module VMEC
using Libdl
#using VMEC_jll
using Requires
using NetCDF
using LinearAlgebra
using StaticArrays
using StructArrays
using CoordinateTransformations
using Interpolations
using Roots
using Polyester

using PlasmaEquilibriumToolkit

include("Exports.jl")
include("VmecTypes.jl")
include("NamelistInput.jl")
#include("FortranInterface.jl")
include("NetCDFUtils.jl")
include("FourierTransformFunctions.jl")
include("VmecUtils.jl")
include("Coordinates.jl")
include("Boozer.jl")
include("Output.jl")

#include("OptimizationTargets.jl")

#=
const libvmec_ref = Ref{String}("")
const libvmec_dlopened = Ref{Bool}(false)

function __init__()
    if Sys.iswindows()
        @debug "ScaLAPACK is not available on Windows, running VMEC is not possible"
    else
        if occursin("Intel",first(Sys.cpu_info()).model)
            libvmec_ref[] = dlopen(libvmec_mkl; throw_error = false) !== nothing ? libvmec_mkl : libvmec_openblas
        else
            libvmec_ref[] = libvmec_openblas
        end
    end
    try
      ccall((:__vmec_ext_interface_MOD_initialize, libvmec_ref[]), Nothing, (Ptr{Int32}, Ptr{Int32}), [4], [4])
      ccall((:__vmec_ext_interface_MOD_finalize, libvmec_ref[]), Nothing, ())
      libvmec_dlopened[] = true
    catch
      @debug "Unable to call VMEC initialize/finalize. Runnng VMEC is not possible"
    end
end
=#

function __init__()
  @require MPI="da04e1cc-30fd-572f-bb4f-1f8673147195" include("FortranInterface.jl")
end

end
